# Overview

data.grandlyon.com is a web platform owned by the Métropole de Lyon, aiming at facilitating and promoting the sharing of (open) data provided by public and private actors of the Lyon metropolitan area.

data.grandlyon.com consists of two macro-components, a Web Portal and a Core:

```plantuml
@startuml

package "data.grandlyon.com" {
  () "API" - [Core]
  [Web Portal] .> [API] : uses
}
@enduml
```

In this respect, the Web Portal is just one among the (hopefully) many Core's clients, in the same way as 3rd-party client applications:

```plantuml
@startuml

package "3rd-party Client Application" {
  [Some Component]
}

package "data.grandlyon.com" {
  () "API" - [Core]
  [Web Portal] .> [API] : uses
}

[Some Component] .> [API] : uses
@enduml
```

**This development project concerns the Web Portal component only.**

## Main features

The data.grandlyon.com's Web Portal includes the following main features:

Concerned entity | ID - Description | Users
--- | ---  | ---
Datasets | F1 - Presenting metadata (title, description, terms, ...) <br> F2 - Showing tabular views of data (if applicable) <br> F3 - Showing map views of data (if applicable) <br> F4 - Showing linked resources (APIs, files) <br> F5 - Performing full-text searches against data and metadata <br> F6 - Performing faceted searches against metadata <br> F7 - Composing custom queries against the Core APIs | end-users
Users  | F8 - Creating/updating/deleting accounts <br> F9 - Performing logins and logouts <br> F10 - Gaining access to restricted-access resources <br> | end-users
Editorial Content | F11 - Editing static pages (approach, terms of use, ...) <br> F12 - Displaying static pages (approach, terms of use, ...) <br> F13 - Editing articles <br> F14 - Displaying articles <br> F15 - Editing the catalog of partners (data producers, ...) <br> F16 - Displaying the catalog of partners (data producers, ...) <br> F17 - Editing the catalog of data reuses (applications, websites, articles, ...) <br> F18 - Displaying the catalog of data reuses (applications, websites, articles, ...) <br> F19 - Editing the catalog of the Open Source initiatives powering this project <br> F20 - Displaying the catalog of the Open Source initiatives powering this project | back-office <br> end-users <br> back-office <br> end-users <br> back-office <br> end-users <br> back-office <br> end-users <br> back-office <br> end-users
Support | F21 - Allowing users to contact the user support | end-users

<!-- * it showcases the datasets hosted by the Core component, presenting:
    * metadata (title, description, terms, ...)
    * tabular view (if applicable)
    * map view (if applicable)
    * linked resources (APIs, files)
* it allows users to
    * perform full-text searches within data and metadata
    * create accounts, establish authenticated sessions
    * gain access to restricted-access datasets
    * compose custom queries against the Core APIs
    * contact the user support, provide feedback
* it shows editorial contents:
    * static pages
    * posts
    * catalogs of
        * partners (data producers, ...)
        * reuses of data (applications, websites, articles, ...)
        * Open Source software the project relies on -->

The data.grandlyon.com's Web Portal also features an independent GUI allowing the back-office users to administer the editorial content.

## Architecture

...an overview...


## Components

### Core components

The following table lists, in alphabetical order, the components of data.grandlyon.com's Core macro-component that are used by the Web Portal:

ID | Name  | Type | Website | Usage
--- | --- | --- | --- | ---
C1 | Legacy AUTH | specific | | AUTHN/AUTHZ service
C2 | PostgreSQL + PostGIS | off-the-shelf |  [Link](https://postgis.net/) | Data Source
C3 | GeoNetwork | off-the-shelf |  [Link](https://www.geonetwork-opensource.org/) | Metadata Catalog
C4 | MapServer | off-the-shelf | [Link](https://mapserver.org/) | WMS and MVT Server

The latter components being provided by the Core macro-component of the data.grandlyon.com platform, their development is beyond the scope of this project.

<!-- Notes:
* The component C1 is deemed as "legacy" because... -->

### Off-the-shelf applications

ID | Name | Website | Usage
--- | --- | --- | ---
A1 | Elasticsearch | [Link](https://www.elastic.co/fr/products/elasticsearch) | Search Engine
A2 | Ghost | [Link](https://ghost.org/) | Headless CMS
A3 | Kong | [Link](https://konghq.com/kong/) | API Gateway
A4 | Matomo | [Link](https://matomo.org/) | Web Analytics
A5 | MinIO | [Link](https://min.io/) | Object Store
A6 | Postfix | [Link](http://www.postfix.org/) | SMTP Server



### Middlewares

ID | Name | Repo | Doc | Usage | Deps
--- | --- | --- | --- | --- | ---
M1 | Legacy AUTH | ... | ... | Facilitating the interaction between the Web Portal Authentication Service (S1) and the AUTHN/AUTHZ Service (C1) hosted by data.grandlyon.com's Core macro-component |  C1, S5

### Proxies

ID | Name | Repo | Doc | Usage | Deps
--- | --- | --- | --- | --- | ---
P1 | Map Proxy | ... | ... | Proxying requests that the Web Portal performs against the cartographic Web Services (WMS, MVT) hosted by data.grandlyon.com's Core macro-component| C4



### Indexers

The following custom indexers are used to index documents in Elasticsearch (A1) in order to make them full-text searchable.

ID | Name | Repo | Doc | Usage | Deps
--- | --- | --- | --- | --- | ---
I1 | Editorial Content | ... | ... | Indexing the posts and pages edited in Ghost | A2
I2 | Metadata and Data | ... | ... | Indexing the metadata and data hosted, respectively, by data.grandlyon.com's catalog (C3) and database (C4) | C3, C4

### Tools

ID | Name | Repo | Doc | Usage | Deps
--- | --- | --- | --- | --- | ---
T1 | MinIO master-slave replication tool | ... | ... | Replicating/mirroring the assets stored in one "master" instance of MinIO to some other "slave" instances | A5



### Services

In alphabetical order:

ID | Name | Repo | Doc | Usage | Deps
--- | --- | --- | --- | --- | ---
S1 | Authentication | ...  | [Link](../components/services/authentication.md) | Allowing users to create accounts and to perform logins and logouts | A3, S5
S2 | Changelog | [Link](https://gitlab.alpha.grandlyon.com/refonte-data/service-changelog)  | [Link](../components/services/changelog.md) | Keeping track of the new features available to users throughout the developments|
S3 | Credits | ... | ... | Catalog of the Open Source initiatives powering the data.grandlyon.com project | S6 |
S4 | CSV Catalog Downloader | ... | ... |  Allowing users to download cached CSV exports of the metadata catalog | C3 |
S5 | Mail | ... | [Link](../components/services/mail.md) | Sending e-mails to both end- and back-office users | A6
S6 | Media Library | ... | ... | Managing the images shown across the various pages of the Web Portal (organizations, posts, ...) |
S7 | Organizations | ... | ... | A catalog of the partners of the data.grandlyon.com, typically Data Providers | S6
S8 | Resources Helper | ... | ... | Assisting users in the composition of custom queries against the Core APIs |
S9 | Reuses | ...  | ...  | A catalog of the known reuses of the data shared through data.grandlyon.com | S6

### Specific applications
ID | Name | Repo | Doc | Usage | Deps
--- | --- | --- | --- | --- | ---
D1 | Web App | ... | ... | Web Application representing the actual Web Portal as seen by its end-users | S[1,9]
D2 | Admin GUI | ... | ... |  Back-office oriented web application allowing users to administrate some of the editorial content as well as the configuration of some functionality | S[1,3], S[6,9]


<!-- <span id="test">mon test</span>
<a href='#test'>link</a> -->
